@@ -282,9 +282,12 @@ class Table(metaclass=MetaTable):
         if data is None:
             raise MissingInput()
 
+        log.info(color.cyan('In a parse %s'), cls.fields)
+
         values = []
         fields = []
         for field, config in cls.fields.items():
+            log.info(color.cyan('Parsing field %s'), field)
             if mode in config and not config[mode]:
                 continue
 
@@ -293,9 +296,10 @@ class Table(metaclass=MetaTable):
                 value = data[field]
 
                 if 'array' in config and config['array']:
-                    if not isinstance(value, list) and not isinstance(value, tuple):
-                        raise InvalidValue('Value of '+field+' must be instance of list '+str(type(value))+' given', field)
-                    value = '{'+(','.join([cls.value(field, parse) for parse in value]))+'}'
+                    if value is not None:
+                        if not isinstance(value, list) and not isinstance(value, tuple):
+                            raise InvalidValue('Value of '+field+' must be instance of list '+str(type(value))+' given', field)
+                        value = '{'+(','.join([cls.value(field, parse) for parse in value]))+'}'
                 else:
                     value = cls.value(field, value)
 
@@ -311,6 +315,8 @@ class Table(metaclass=MetaTable):
 
     @classmethod
     def value(cls, field, value):
+        if value is None:
+            return None
 
         config = cls.fields[field]
 
@@ -507,7 +513,7 @@ class Table(metaclass=MetaTable):
 
     @classmethod
     def save(cls, id, data):
-        update = Table.update(data)
+        update = cls.update(data)
         try:
             db = cls.get_db()
             cursor = db.cursor()
@@ -527,12 +533,40 @@ class Table(metaclass=MetaTable):
 
     @classmethod
     def add(cls, data):
-        pass
+        insert = cls.insert(data)
+        try:
+            db = cls.get_db()
+            cursor = db.cursor()
+            cursor.execute(*debug(f"""INSERT INTO {cls}
+                                    SET ({insert.fields()})
+                                    VALUES ({insert.fields('%s')})
+                                    RETURNING {cls.select()}""",
+                                insert.values()))
+            result = cls.create(cursor.fetchone())
+        except Exception as error:
+            raise error
+        finally:
+            db.commit()
+            cls.put_db(db)
+
+        return result
 
     @classmethod
-    def delete(cls, data):
-        pass
+    def delete(cls, id):
+        try:
+            db = cls.get_db()
+            cursor = db.cursor()
+            cursor.execute(*debug(f"""DELETE FROM {cls}
+                                    WHERE {cls('id')}=%s""",
+                                (id,)))
+            return bool(cursor.rowcount)
+        except Exception as error:
+            raise error
+        finally:
+            db.commit()
+            cls.put_db(db)
 
+        return False
 
 class Row:
     def __init__(self):
